/*
 * $Id: NonRootServletTestCase.java 22477 2011-07-20 15:27:35Z justin.calleja $
 * --------------------------------------------------------------------------------------
 * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
 *
 * The software in this package is published under the terms of the CPAL v1.0
 * license, a copy of which has been included with this distribution in the
 * LICENSE.txt file.
 */

package org.mule.module.cxf;

public class NonRootServletTestCase extends ServletTestCase
{
    public NonRootServletTestCase(ConfigVariant variant, String configResources)
    {
        super(variant, configResources);
    }

    @Override
    protected String getContextPath()
    {
        return "/foo";
    }
}


